/*
 * @dictionary		ep.dict
 *
 * @translation		{Gadget}
 */

(function(){
	var selectedNode,
		epDict = ep.dict('ep.dict'),
		translations = {
			tGadget: epDict.translate('Gadget')
		};

	function createImgSrc( data ){
		var srcValue = ep.config.iconsRoot + "/gadget";
			if(data){
				srcValue += "_" + data.alias;
				var opt = data.options;
				if(opt && data.alias == 'maps'){
					if(opt.layout){
						srcValue += "_" + opt.layout;
					}
					if(opt.type){
						srcValue += "_" + opt.type;
					}
				}
			}
			srcValue +=".png";
			return srcValue;
	};


	CKEDITOR.plugins.add( 'epgadget',{
		init: function( editor ){
			editor.addCommand( 'epgadget',{
					exec : function( editor, alias ){
						var gadgetOptions = {
							callback: function(data){
									var imgSrc = createImgSrc(data);
									var element = new CKEDITOR.dom.element("div");
									var dataString = JSON.stringify(data);
									element.setAttributes({
										'class': 'ep-gadget',
										'data-ep-gadget': dataString
										});
									//create FakeElement which is used as placeholder
									var FakeElement = editor.createFakeElement(element, "ep-gadget", "div");
									FakeElement.setAttributes({
										'alt': translations.tGadget, //'Gadget',
										'title': translations.tGadget, //'Gadget',
										'data-ep-gadget': dataString,
										'contenteditable': false,
										'style': 'max-width:100%;display:block;margin-bottom:10px;',
										'src': imgSrc
									});

									//remove selected element if gadget was selected before
									if(selectedNode){
										var selectedElement = selectedNode.getSelectedElement();
										if(selectedElement){
											selectedElement.remove();
										}

									}
									editor.insertElement(FakeElement);
								}
							};
							//check if gadget is selected and get gadget data from fake element
								selectedNode = editor.getSelection();
								if(selectedNode){
									var selectedElement = selectedNode.getSelectedElement();
									if(selectedElement){
										var dataAttribute = selectedElement.getAttribute('data-ep-gadget');
										if(dataAttribute){
											gadgetOptions.gadget = jQuery.parseJSON(dataAttribute);
										}
									}
								}

								if(alias && alias == 'rss' && !gadgetOptions.gadget){
									gadgetOptions.gadget = { alias : 'rss'};
								}

						var topFrame = window;
						if (window.top !== window.self) {
							try {
								topFrame = window.top;
							}
							catch (error) {}
						}
						topFrame.jQuery.ready('de_epages.externalcontent.gadgets', function ($) {
							if(gadgetOptions.gadget && gadgetOptions.gadget.alias === "twitter" && (gadgetOptions.gadget.options.type === "profile" || gadgetOptions.gadget.options.type === "search")){
								gadgetOptions.gadget.options = {};
							}
							topFrame.de_epages.externalcontent.gadgets(gadgetOptions);
						});
					}
				});
			editor.ui.addButton( 'epgadget',{
				label: translations.tGadget,
				command: 'epgadget',
				icon: this.path + 'images/gadget.png',
				onRender: function(){
					//highlight gadget button on gadget select
					editor.on( 'selectionChange', function( ev ){
						this.setState(CKEDITOR.TRISTATE_OFF );

						if(ev.data && ev.data.selection && ev.data.selection.getSelectedElement()!=null && ev.data.selection.getSelectedElement().hasClass('ep-gadget')){
							this.setState(CKEDITOR.TRISTATE_ON);
						}
					},this);
				}
			});
			editor.on( 'doubleclick', function( ev )
			{
				if (ev.data && ev.data.element && ev.data.element.hasClass('ep-gadget')) {
					editor.execCommand('epgadget');
				}
			});

		},

		afterInit : function( editor )	{
			var dataProcessor = editor.dataProcessor,
				dataFilter = dataProcessor && dataProcessor.dataFilter;
				if ( dataFilter ){
					dataFilter.addRules({
						elements :{
							div : function( element ){
								//select gadget and replace it with Fake element
								if(element.attributes['class'] == "ep-gadget"){
									var FakeElement = editor.createFakeParserElement(element, "ep-gadget", "div", false);
									var dataString = jQuery("<div/>").html(element.attributes['data-ep-gadget']).text(),
										data = jQuery.parseJSON(dataString),
										opt = data.options,
										imgSrc = createImgSrc(data);
									//we have to use FakeElement.attributes here because there is no setAttributes method for a FakeParserElement - very strange
									FakeElement.attributes.title = translations.tGadget;
									FakeElement.attributes.alt = translations.tGadget;
									FakeElement.attributes.style = "max-width:100%;display:block;margin-bottom:10px;";
									FakeElement.attributes.src = imgSrc;
									FakeElement.attributes.contenteditable = false;
									FakeElement.attributes['data-ep-gadget'] = dataString;
									return FakeElement;
								}
							}
						}
					});
				}
			}
	} );
})();